--
-- Client window mover
--
-- By Tom Payne <ion at tompayne.org> and
--    Tuomo Valkonen <tuomov at iki.fi>
--
--
-- With this code, you can instantly move client windows on Ion
-- workspaces to adjacent frames using keyboard shortcuts. The
-- bindings specified in the example code are as follows:
--
-- key          function
-- -------------------------------------
-- Ctrl+Alt+H   move window leftwards
-- Ctrl+Alt+J   move window downwards
-- Ctrl+Alt+K   move window upwards
-- Ctrl+Alt+L   move window rightwards
--
-- Add the code to ionws.lua to make use of it.
--

function ionws_move_current(frame, dir)
    local ws = frame
    while ws and not obj_is(ws, "WIonWS") do
        ws = ws:manager()
    end
    if not ws then return end
    local c = frame:current()
    local other = nil
    if dir == "left" then
        other = ws:left_of(frame) or ws:rightmost()
    elseif dir == "right" then
        other = ws:right_of(frame) or ws:leftmost()
    elseif dir == "up" then
        other = ws:above(frame) or ws:lowest()
    elseif dir == "down" then
        other = ws:below(frame) or ws:topmost()
    else
        return
    end
    if c and obj_is(other, "WMPlex") then
        other:attach(c, { switchto = true })
    end
    if other then
        other:goto()
    end
end

ionframe_bindings{
    kpress(DEFAULT_MOD.."Control+H",
           function(frame) ionws_move_current(frame, "left" ) end),
    kpress(DEFAULT_MOD.."Control+J",
           function(frame) ionws_move_current(frame, "down" ) end),
    kpress(DEFAULT_MOD.."Control+K",
           function(frame) ionws_move_current(frame, "up"   ) end),
    kpress(DEFAULT_MOD.."Control+L",
           function(frame) ionws_move_current(frame, "right") end),
}
